@@ -35,6 +35,7 @@ class CommonGeometry:
         self._AFTER_SYNC_QUEUE = []
         self._SIZE_QUEUE = []
         self._PHYSICAL_QUEUE = []
+        self._OUTWARD_NORMALS = []
 
     def __enter__(self):
         gmsh.initialize()
@@ -324,11 +325,13 @@ class CommonGeometry:
             if label is not None:
                 gmsh.model.setPhysicalName(d, tag, label)
 
+        for entity in self._OUTWARD_NORMALS:
+            gmsh.model.mesh.setOutwardOrientation(entity.id)
+
         if order is not None:
             gmsh.model.mesh.setOrder(order)
 
-        if verbose:
-            gmsh.option.setNumber("General.Terminal", 1)
+        gmsh.option.setNumber("General.Terminal", 1 if verbose else 0)
 
         # set algorithm
         # http://gmsh.info/doc/texinfo/gmsh.html#index-Mesh_002eAlgorithm
