@@ -19,13 +19,14 @@ class Line(LineBase):
         List containing the begin and end points of the line.
     """
 
-    dimension = 1
+    dim = 1
 
     def __init__(self, env, p0, p1):
         assert isinstance(p0, Point)
         assert isinstance(p1, Point)
         id0 = env.addLine(p0._ID, p1._ID)
-        self.dim_tags = [(1, id0)]
+        self.dim_tag = (1, id0)
+        self.dim_tags = [self.dim_tag]
         super().__init__(id0, [p0, p1])
 
     def __repr__(self):
