@@ -15,7 +15,7 @@ class Box:
         Characteristic length of the mesh elements of this polygon.
     """
 
-    dimension = 3
+    dim = 3
 
     def __init__(self, x0, extents, char_length=None):
         assert len(x0) == 3
@@ -23,4 +23,5 @@ class Box:
         self.x0 = x0
         self.extents = extents
         self._ID = gmsh.model.occ.addBox(*x0, *extents)
-        self.dim_tags = [(3, self._ID)]
+        self.dim_tag = (3, self._ID)
+        self.dim_tags = [self.dim_tag]
